# HyperRED

**EMNLP 2022**: [A Dataset for Hyper-Relational Extraction and a Cube-Filling Approach](https://aclanthology.org/2022.emnlp-main.688/)

**Hugging Face**: [`declare-lab/HyperRED`](https://huggingface.co/datasets/declare-lab/HyperRED)

**GitHub**: [`declare-lab/HyperRED`](https://github.com/declare-lab/HyperRED)


HyperRED is a hyper-relational dataset.
Each relation in HyperRED has a main head and tail, but can have any number of additional qualifiers.

The train set is generated by distant supervision, while the validation and test sets are human-annotated.
